@@ -7,11 +7,12 @@ import hildon
 from os import listdir, path, system
 from ConfigParser import SafeConfigParser
 
-version = "1.3-1"
+version = "1.4-0"
 autostart = False
 confirmDisconnect = True
 showConnected = True
 stopTracking = False
+keepWifiPMOff = False
 skipSystemCheck = False
 connectedIcon = "Symbol"
 
@@ -19,8 +20,9 @@ class Main(object):
     def __init__(self):
         global autostart
         global confirmDisconnect
-        global stopTracking
         global showConnected
+        global stopTracking
+        global keepWifiPMOff
         global skipSystemCheck
         global connectedIcon
         autostartDisabled = False
@@ -41,6 +43,7 @@ class Main(object):
             self.parser.set('options', 'confirmDisconnect', str(confirmDisconnect))
             self.parser.set('options', 'showConnected', str(showConnected))
             self.parser.set('options', 'stopTracking', str(stopTracking))
+            self.parser.set('options', 'keepWifiPMOff', str(keepWifiPMOff))
             self.parser.set('options', 'skipSystemCheck', str(skipSystemCheck))
             self.parser.set('options', 'connectedIcon', str(connectedIcon))
             self.parser.write(configFile)
@@ -60,6 +63,10 @@ class Main(object):
                     stopTracking = self.parser.getboolean('options', 'stopTracking')
                 else:
                     self.parser.set('options', 'stopTracking', str(stopTracking))
+                if self.parser.has_option('options', 'keepWifiPMOff'):
+                    keepWifiPMOff = self.parser.getboolean('options', 'keepWifiPMOff')
+                else:
+                    self.parser.set('options', 'keepWifiPMOff', str(keepWifiPMOff))
                 if self.parser.has_option('options', 'skipSystemCheck'):
                     skipSystemCheck = self.parser.getboolean('options', 'skipSystemCheck')
                 else:
@@ -97,12 +104,15 @@ class Main(object):
         window.set_title("OpenSSH Status Widget")
         window.connect("delete_event", gtk.main_quit, None)
         
-        labelServer = gtk.Label("Server options:")
         labelWidget = gtk.Label("Widget options:")
+        labelOther = gtk.Label("Other options:")
     
         self.buttonAutostart = hildon.CheckButton(gtk.HILDON_SIZE_FULLSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
         self.buttonAutostart.set_label("Run server at system startup")
                 
+        self.buttonKeepWifiPMOff = hildon.CheckButton(gtk.HILDON_SIZE_FULLSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
+        self.buttonKeepWifiPMOff.set_label("Keep WiFi power management off when connected")
+    
         self.buttonConfirm = hildon.CheckButton(gtk.HILDON_SIZE_FULLSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT)
         self.buttonConfirm.set_label("Confirm when disconnecting")
         
@@ -125,13 +135,14 @@ class Main(object):
         vboxBorder.set_border_width(8)
         vbox = gtk.VBox(False, 0)
         vbox.set_border_width(0)
-        vbox.pack_start(labelServer, False, False, 12)
-        vbox.pack_start(self.buttonAutostart, False, False, 0)
         vbox.pack_start(labelWidget, False, False, 12)
         vbox.pack_start(self.buttonConfirm, False, False, 0)
         vbox.pack_start(self.buttonShowConnected, False, False, 0)
         vbox.pack_start(self.buttonConnectedIcon, False, False, 0)
         vbox.pack_start(self.buttonStopTracking, False, False, 0)
+        vbox.pack_start(labelOther, False, False, 12)
+        vbox.pack_start(self.buttonAutostart, False, False, 0)
+        vbox.pack_start(self.buttonKeepWifiPMOff, False, False, 0)
         
         areaScrolling = hildon.PannableArea()
         areaScrolling.add_with_viewport(vbox)
@@ -159,12 +170,18 @@ class Main(object):
             self.buttonStopTracking.set_active(True)
         else:
             self.buttonStopTracking.set_active(False)
+        if keepWifiPMOff:
+            self.buttonKeepWifiPMOff.set_active(True)
+        else:
+            self.buttonKeepWifiPMOff.set_active(False)
+            
             
         self.buttonAutostart.connect("clicked", self.buttonAutostart_clicked)
         self.buttonConfirm.connect("clicked", self.buttonConfirm_clicked)
         self.buttonShowConnected.connect("clicked", self.buttonShowConnected_clicked)
         self.buttonConnectedIcon.connect("value-changed", self.buttonConnectedIcon_changed)
         self.buttonStopTracking.connect("clicked", self.buttonStopTracking_clicked)
+        self.buttonKeepWifiPMOff.connect("clicked", self.buttonKeepWifiPMOff_clicked)
         
         menu = self.create_menu()
         window.set_app_menu(menu)
@@ -216,6 +233,12 @@ class Main(object):
         self.parser.set('options', 'stopTracking', str(stopTracking))
         self.write_config()
         
+    def buttonKeepWifiPMOff_clicked(self, dummy):
+        global keepWifiPMOff
+        keepWifiPMOff = not keepWifiPMOff
+        self.parser.set('options', 'keepWifiPMOff', str(keepWifiPMOff))
+        self.write_config()
+        
     def write_config(self):
         configFile = open('/home/user/.openssh-status-widget', 'r+')
         self.parser.write(configFile)
