@@ -16,6 +16,7 @@ class opensshStatus(hildondesktop.StatusMenuItem):
         self.confirmDisconnect = True
         self.showConnected = True
         self.stopTracking = False
+        self.keepWifiPMOff = True
         self.skipSystemCheck = False
         connectedIcon = "symbol"
         if path.isfile("/home/user/.openssh-status-widget"):
@@ -30,6 +31,8 @@ class opensshStatus(hildondesktop.StatusMenuItem):
                 self.showConnected = parser.getboolean('options', 'showConnected')
             if parser.has_option('options', 'stopTracking'):
                 self.stopTracking = parser.getboolean('options', 'stopTracking')
+            if parser.has_option('options', 'keepWifiPMOff'):
+                self.keepWifiPMOff = parser.getboolean('options', 'keepWifiPMOff')
             if parser.has_option('options', 'skipSystemCheck'):
                 self.skipSystemCheck = parser.getboolean('options', 'skipSystemCheck')
             if parser.has_option('options', 'connectedIcon'):
@@ -55,6 +58,7 @@ class opensshStatus(hildondesktop.StatusMenuItem):
         self.on = False
         self.connected = False
         self.refresh = False
+        self.refreshWifiPMOff = False
         self.sshJustOff = 0
         
         self.start()
@@ -186,6 +190,13 @@ class opensshStatus(hildondesktop.StatusMenuItem):
             if self.sshRunning and not self.sshConnected and self.connected:
                 self.connected = False
                 self.set_status_area_icon(self.icon)
+        if self.sshConnected and self.keepWifiPMOff:
+            if not self.refreshWifiPMOff:
+                self.refreshWifiPMOff = True
+            subprocess.call(["sudo", "/usr/sbin/openssh-status.sh", "disable_wifipm"])
+        elif self.refreshWifiPMOff:
+            self.refreshWifiPMOff = False
+            subprocess.call(["sudo", "/usr/sbin/openssh-status.sh", "enable_wifipm"])
         if self.sshConnected == 1:
             self.button.set_text("OpenSSH Server", str(self.sshConnected)+" connection")
             return True
