@@ -37,11 +37,18 @@ if [ "$1" = "insert_start" ] ; then
         sed -i '1i#start on stopped rcS' /etc/event.d/sshd
 fi
 
-if [ "$1" = "enable_autostart" ] ; then
-        sed -i 's/#start on stopped rcS/start on stopped rcS/g' /etc/event.d/sshd
-fi
-
 if [ "$1" = "disable_autostart" ] ; then
         sed -i 's/start on stopped rcS/#start on stopped rcS/g' /etc/event.d/sshd
 fi
 
+if [ "$1" = "enable_autostart" ] ; then
+        sed -i 's/#start on stopped rcS/start on stopped rcS/g' /etc/event.d/sshd
+fi
+
+if [ "$1" = "disable_wifipm" ] ; then
+        iwconfig wlan0 power off
+fi
+
+if [ "$1" = "enable_wifipm" ] ; then
+        iwconfig wlan0 power on
+fi
